@@ -1,5 +1,7 @@
-from .client import Client
-from .exceptions import (
+import os
+
+from .client import Client  # noqa
+from .exceptions import (  # noqa
     HTTPError,
     BadRequestsError,
     UnauthorizedError,
@@ -14,3 +16,7 @@ from .exceptions import (
     GatewayTimeoutError
 )
 
+
+dir_path = os.path.dirname(os.path.realpath(__file__))
+if os.path.isfile(os.path.join(dir_path, 'VERSION.txt')):
+    __version__ = open(os.path.join(dir_path, 'VERSION.txt')).read().strip()
